@@ -5,9 +5,9 @@
 #' (if \code{channels} is not empty).
 #'
 #' @param ... objects to store in the R data file
-#' @param channels slack.com channels to save to (optional)
+#' @param channels Slack channels to save to (optional)
 #' @param file filename (without extension) to use
-#' @param api_token full API token
+#' @param bot_user_oauth_token Slack bot user OAuth token
 #' @rdname save_slackr
 #' @note You can pass in \code{add_user=TRUE} as part of the \code{...} parameters and the Slack API
 #'       will post the message as your logged-in user account (this will override anything set in
@@ -21,14 +21,14 @@
 #' }
 save_slackr <- function(..., channels="",
                         file="slackr",
-                        api_token=Sys.getenv("SLACK_API_TOKEN")) {
+                        bot_user_oauth_token=Sys.getenv("SLACK_BOT_USER_OAUTH_TOKEN")) {
 
 
   loc <- Sys.getlocale('LC_CTYPE')
   Sys.setlocale('LC_CTYPE','C')
   on.exit(Sys.setlocale("LC_CTYPE", loc))
 
-  ftmp <- tempfile(file, fileext=".rda")
+  ftmp <- tempfile(file, fileext=".Rdata")
   save(..., file=ftmp)
 
   on.exit(unlink(ftmp), add=TRUE)
@@ -39,8 +39,8 @@ save_slackr <- function(..., channels="",
   res <-httr::POST(url="https://slack.com/api/files.upload",
                    httr::add_headers(`Content-Type`="multipart/form-data"),
                    body=list(file=httr::upload_file(ftmp),
-                             filename=sprintf("%s.rda", file),
-                             token=api_token,
+                             filename=sprintf("%s.Rdata", file),
+                             token=bot_user_oauth_token,
                              channels=modchan))
 
   stop_for_status(res)
