@@ -1,14 +1,14 @@
 #' Send a file to Slack
 #'
-#' \code{slackrUpload} enables you upload files to Slack and
+#' \code{slackr_upload} enables you upload files to Slack and
 #' (optionally) post them to one or more channels (if \code{channels} is not empty).
 #'
 #' @rdname slackr_upload
 #' @param filename path to file
-#' @param title title on slack (optional - defaults to filename)
+#' @param title title on Slack (optional - defaults to filename)
 #' @param initial_comment comment for file on slack (optional - defaults to filename)
-#' @param channels slack.com channels to save to (optional)
-#' @param api_token full API token
+#' @param channels Slack channels to save to (optional)
+#' @param bot_user_oauth_token Slack bot user OAuth token
 #' @return \code{httr} response object from \code{POST} call (invisibly)
 #' @author Quinn Weber [ctb], Bob Rudis [aut]
 #' @references \url{https://github.com/hrbrmstr/slackr/pull/15/files}
@@ -16,7 +16,7 @@
 #' @export
 slackr_upload <- function(filename, title=basename(filename),
                           initial_comment=basename(filename),
-                          channels="", api_token=Sys.getenv("SLACK_API_TOKEN")) {
+                          channels="", bot_user_oauth_token=Sys.getenv("SLACK_BOT_USER_OAUTH_TOKEN")) {
 
   f_path <- path.expand(filename)
 
@@ -28,16 +28,18 @@ slackr_upload <- function(filename, title=basename(filename),
     Sys.setlocale('LC_CTYPE','C')
     on.exit(Sys.setlocale("LC_CTYPE", loc))
 
-    modchan <- slackrChTrans(channels)
+    modchan <- slackrChTrans(channels, bot_user_oauth_token)
 
     res <- httr::POST(url="https://slack.com/api/files.upload",
                       httr::add_headers(`Content-Type`="multipart/form-data"),
                       body=list( file=httr::upload_file(f_path), filename=f_name,
                                  title=title, initial_comment=initial_comment,
-                                 token=api_token, channels=paste(modchan, collapse=",")))
+                                 token=bot_user_oauth_token, channels=paste(modchan, collapse=",")))
 
     return(invisible(res))
 
+  } else {
+    stop(sprintf("File [%s] not found", f_path), call.=FALSE)
   }
 
 }
